use std::sync::Arc;

use galactica_content::Outfit;

/// An action the player wants to take in the game.
#[derive(Debug, Clone)]
pub enum PlayerDirective {
	/// Do nothing
	None,

	/// Set main engine state
	Engine(bool),

	/// Set left turn thruster state
	TurnLeft(bool),

	/// Set right turn thruster state
	TurnRight(bool),

	/// Set main gun state
	Guns(bool),

	/// Land on the currently selected planet
	Land,

	/// Take off from the planet we're landed on
	UnLand,

	/// Buy an outfit.
	/// This directive is ignored if the player does not have enough
	/// credits to buy the given number of outfits.
	BuyOutfit {
		/// The outfit to buy
		outfit: Arc<Outfit>,

		/// How many of this outfit to buy
		count: u32,
	},

	/// Sell an outfit.
	/// This directive is ignored if the player does not have enough
	/// outfits to sell.
	SellOutfit {
		/// The outfit to sell
		outfit: Arc<Outfit>,

		/// How many of this outfit to sell
		count: u32,
	},
}
